#
# spec file for package python-requests-oauthlib
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-requests-oauthlib
Version:        1.3.1
Release:        150400.12.3.1
Summary:        OAuthlib authentication support for Requests
License:        ISC
URL:            https://github.com/requests/requests-oauthlib
Source:         https://files.pythonhosted.org/packages/source/r/requests-oauthlib/requests-oauthlib-%{version}.tar.gz
BuildRequires:  %{python_module oauthlib >= 3.0.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.0.0}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-oauthlib >= 3.0.0
Requires:       python-requests >= 2.0.0
BuildArch:      noarch
%python_subpackages

%description
This project provides first-class OAuth library support for Requests.

%prep
%setup -q -n requests-oauthlib-%{version}

%build
%python_build

%install
%python_install

#hardlink duplicated files
%fdupes %{buildroot}

%check
# Three tests initiate network traffic to httpbin.org
%pytest -k 'not (testCanPostBinaryData or test_content_type_override or test_url_is_native_str)'

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst
%{python_sitelib}/*

%changelog
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Thu Apr 14 2022 steven.kowalik@suse.com
- Remove unneeded BuildRequires on mock.
* Tue Feb 15 2022 dmueller@suse.com
- update to 1.3.1:
  * Add initial support for OAuth Mutual TLS (draft-ietf-oauth-mtls)
  * Add eBay compliance fix
  * Add Spotify OAuth 2 Tutorial
  * Add support for python 3.8, 3.9
  * Fixed LinkedIn Compliance Fixes
  * Fixed ReadTheDocs Documentation and sphinx errors
  * Moved pipeline to GitHub Actions
* Wed Sep 29 2021 steven.kowalik@suse.com
- Use pytest to run the testsuite.
* Mon Mar  2 2020 dmueller@suse.com
- update to 1.3.0:
  * Instagram compliance fix
  * Added ``force_querystring`` argument to fetch_token() method on OAuth2Session
* Sun Feb 17 2019 jayvdb@gmail.com
- Activate test suite, skipping three online tests
- Update to version 1.2.0
  * This project now depends on OAuthlib 3.0.0 and above.
  * Updated oauth2 tests to use 'sess' for an OAuth2Session instance instead
    of auth because OAuth2Session objects and methods acceept an auth
    paramether which is typically an instance of requests.auth.HTTPBasicAuth
  * OAuth2Session.fetch_token previously tried to guess how and where to
    provide "client" and "user" credentials incorrectly. This was
    incompatible with some OAuth servers and incompatible with breaking
    changes in oauthlib that seek to correctly provide the client_id.
    The older implementation also did not raise the correct exceptions when
    username and password are not present on Legacy clients.
  * Avoid automatic netrc authentication for OAuth2Session.
- from v1.1.0
  * Adjusted version specifier for oauthlib dependency
  * Dropped dependency on nose.
  * Minor changes to clean up the code and make it more readable/maintainable.
- from v1.0.0
  * Removed support for Python 2.6 and Python 3.3.
  * Added several examples to the documentation.
  * Added plentymarkets compliance fix.
  * Added a token property to OAuth1Session, to match the corresponding
    token property on OAuth2Session.
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Apr 26 2017 pousaduarte@gmail.com
- Update to version 0.8.0:
  * Convert package to singlespec
  * Added Outlook Calender API example
  * Mentioned file to example.rst
  * Update google.rst
  * Allow OAuth2 session request() to take client_id and client_secret
  * Add requests-mock to tox dependencies.
  * Strips new lines in fetch_token  response body
  * Prefer user-supplied auth credentials.
  * add a fitbit compliance fix
  * test successful fitbit auth calls as well
  * v0.8.0
* Mon Jan 30 2017 tbechtold@suse.com
  update to version v0.7.0
  * Subclass requests.auth.AuthBase
  * Allow fetch_token to run through a proxy
  * Cleaning the previous token before fetching a new one, to avoid a
    TokenExpiredError
  * Adapts previous commit
  * Don't nullify token before refresh
  * oauthlib raises a different error from what we expect
  * Date for 0.4.2 release is added to HISTORY
  * v0.6.2
  * Adding Backend Application Flow documentation
  * v0.6.0
  * v0.6.1
  * opt in to Travis container infrastructure
  * minor fix to the previous commit
  * v0.7.0
  * Fix TypeError in TokenMissing class (call to parent)
  * Added authorization header for token access
  * Be more explicit about Travis installing unittest2
  * OAuth1 tests for authorized boolean
  * Only set default headers if headers are None
  * rst syntax fix
  * Google has changed OAuth 2.0 endpoints
  * Use client_id and client_secret as basic auth credentials if provided
  * Add installation instructions to docs index
  * Add **request_kwargs to fetch_request_token and fetch_access_token in
    oauth1_session to be passed to post-method of requests.session
  * Allow OAuth2 session request() to take client_id and client_secret
  * typo in error message
  * Add requests-mock to tox dependencies.
  * Prune .pyc files when creating a release
  * Update google.rst
  * Test 3.5 on Travis
  * Use unittest2 when it is installed
  * Completely remove username/password basic auth logic branch
  * Add setters/getters for client_id and access_token
  * Fix up line-length in note.
  * attach the entire response object when raising TokenRequestDenied
  * MailChimp compliance fixes that work around oauthlib issue #296
  * Allow explicit bypass of basic auth logic branch
  * Add imports for Legacy Application Flow docs
  * add license title
  * Need signedtoken extra for oauthlib dependency
  * Include import in Backend Application Flow docs
  * cleaning code and checking that a password was supplied along username
  * Update real_world_example.rst
  * Added tests for OAuth2 authorized boolean
  * Keep the username/password basic auth logic branch
  * Fix typo
  * [bugfix] Add headers in refresh_token flow
  * Setter/getter for self.token
  * Don't intercept HTTP errors before OAuthlib can handle them
  * Add tox.ini
  * Verify return value of OAuth2 response (#178)
  * Fix a problem that its get method always returns 'not_authed' on Slack
  * Update Legacy Application Flow documentation
  * Check if client exists before referencing client_id
  * Response objects should have cookies, not cookes
  * Preventing sending Basic Auth headers with "None:None"
  * Users should be able to override the token when using the Slack compliance
    fix
  * cleanup docstring of OAuth1Session to fix a typo/usage error
  * Allows tokens to be refreshed via a proxy
  * Add unittest2 test dependency for Python 2.6
  * Skip rsa tests when dependencies not met
  * fixed the layout of the note
  * Rename _refresh flag to withhold_token
  * Use requests-mock library, add tests for Slack compliance fix
  * Remove misleading README example.
  * added note to the real world example explaining its caveats
  * v0.5.0
  * making operator precedence more readable
  * When refreshing tokens, pass through **kwargs
- Use pypi.io as Source url
* Thu Mar 26 2015 prusnak@opensuse.org
- updated to 0.4.2:
  - New ``authorized`` property on OAuth1Session and OAuth2Session,
    which allows you to easily determine if the session is already
    authorized with OAuth tokens or not.
  - New ``TokenMissing`` and ``VerifierMissing`` exception classes
    for OAuth1Session: this will make it easier to catch and identify
    these exceptions.
* Wed Jul 23 2014 mcihar@suse.cz
- Upgrade to 0.4.1:
  - New install target ``[rsa]`` for people using OAuth1 RSA-SHA1 signature
    method.
  - Fixed bug in OAuth2 where supplied state param was not used in auth url.
  - OAuth2 HTTPS checking can be disabled by setting environment variable
    ``OAUTHLIB_INSECURE_TRANSPORT``.
  - OAuth1 now re-authorize upon redirects.
  - OAuth1 token fetching now raise a detailed error message when the
    response body is incorrectly encoded or the request was denied.
  - Added support for custom OAuth1 clients.
  - OAuth2 compliance fix for Sina Weibo.
  - Multiple fixes to facebook compliance fix.
  - Compliance fixes now re-encode body properly as bytes in Python 3.
  - Logging now properly done under ``requests_oauthlib`` namespace instead
    of piggybacking on oauthlib namespace.
  - Logging introduced for OAuth1 auth and session.
* Thu Nov  7 2013 mcihar@suse.cz
- initial packaging
